; 
; Button Handling
; 
; Routines for the handling of input pins for button handling
;
;
; Andreas Tnne
; atoenne@t-online.de
;
; No copyright. This is free software. Thank you for naming the author
;
; Web released version 1.0

; ******************** USAGE *************************
;
; .SET BUTTONPort				The port name/number where buttons are read
; .SET BUTTONMask				The bit mask for the input lines that are button inputs
; .DEF Scratch					General scratch register for arbitrary value changes
; .DEF BUTTONValue				Button read values

; Note: the port configuration has to be done manually
; Note: we assume that the port pins are pulled high when a button is not pressed


;***** ButtonReadWait ******
; Read the current button status into BUTTONValue and wait until all buttons are released again
; Debounce the button by looping until the read button status is stable for 5ms
; BUTTONValue = the bits of the buttons defined by BUTTONMask

ButtonReadWait:
	in BUTTONValue, BUTTONPort			; read the reference value
	com BUTTONValue
	andi BUTTONValue, BUTTONMask
	breq ButtonReadWaitEnd				; do not continue reading if no button pressed at the moment
	Delay 5000							; wait 5ms
	in Scratch, BUTTONPort
	com Scratch
	andi Scratch, BUTTONMask
	cp BUTTONValue, Scratch
	brne ButtonReadWait
ButtonReadWaitRelease:					; now poll until all buttons are released
	in Scratch, BUTTONPort
	com Scratch
	andi Scratch, BUTTONMask
	brne ButtonReadWaitRelease
ButtonReadWaitEnd:
	ret

